@@ -58,6 +58,9 @@ class VkontakteIframeForm(forms.Form):
     # ключ, необходимый для авторизации пользователя на стороннем сервере
     auth_key = forms.CharField()
 
+    # access token для вызова методов Vkontakte API
+    access_token = forms.CharField()
+
     # id языка пользователя, просматривающего приложение
     language = forms.ChoiceField(LANGUAGE_CHOICES)
 
@@ -115,8 +118,11 @@ class VkontakteIframeForm(forms.Form):
             if language[0] == int(self.cleaned_data['language']):
                 lang_code = language[1]
                 break
-        if check_for_language(lang_code):
-            return lang_code
+        try:
+            if check_for_language(lang_code):
+                return lang_code
+        except AttributeError:
+            pass
         return None
 
 
